@@ -1,7 +1,14 @@
+import logging
 import yaml
 import re
 from pathlib import Path
 
+# Allowed metabase.* fields
+_META_FIELDS = [
+    'special_type', 
+    'visibility_type'
+]
+
 class DbtReader:
     """Reader for dbt project configuration.
     """
@@ -81,12 +88,13 @@ class DbtReader:
                     mb_column['special_type'] = 'type/FK'
                     mb_column['fk_target_table'] = self.parse_ref(relationships['to']).upper()
                     mb_column['fk_target_field'] = relationships['field'].upper()
-                elif 'metabase.field' in test:
-                    metabase = test['metabase.field']
-                    if not mb_column.get('special_type'):
-                        mb_column['special_type'] = metabase.get('special_type')
-                    mb_column['visibility_type'] = metabase.get('visibility_type')
         
+        if 'meta' in column:
+            meta = column.get('meta')
+            for field in _META_FIELDS:
+                if f'metabase.{field}' in meta:
+                    mb_column[field] = meta[f'metabase.{field}']
+
         return mb_column
 
     @staticmethod
